==> cyrus-imapd_3.10.0~rc2.orig.tar.xz: cyrus-imapd-3.10.0-rc2/imap/vcard_support.h <==
/* vcard_support.h -- Helper functions for vcard
 *
 * Copyright (c) 1994-2016 Carnegie Mellon University.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The name "Carnegie Mellon University" must not be used to
 *    endorse or promote products derived from this software without
 *    prior written permission. For permission or any legal
 *    details, please contact
 *      Carnegie Mellon University
 *      Center for Technology Transfer and Enterprise Creation
 *      4615 Forbes Avenue
 *      Suite 302
 *      Pittsburgh, PA  15213
 *      (412) 268-7393, fax: (412) 268-7395
 *      innovation@andrew.cmu.edu
 *
 * 4. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by Computing Services
 *     at Carnegie Mellon University (http://www.cmu.edu/computing/)."
 *
 * CARNEGIE MELLON UNIVERSITY DISCLAIMS ALL WARRANTIES WITH REGARD TO
 * THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS, IN NO EVENT SHALL CARNEGIE MELLON UNIVERSITY BE LIABLE
 * FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
 * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
 * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 */

#ifndef VCARD_SUPPORT_H
#define VCARD_SUPPORT_H

#include <config.h>

#include "vparse.h"

#include "mailbox.h"
#include "message_guid.h"
#include "util.h"

extern struct vparse_card *vcard_parse_string(const char *str);
extern struct vparse_card *vcard_parse_buf(const struct buf *buf);
extern struct buf *vcard_as_buf(struct vparse_card *vcard);

extern struct vparse_card *record_to_vcard(struct mailbox *mailbox,
                                           const struct index_record *record);

extern size_t vcard_prop_decode_value(struct vparse_entry *prop,
                                      struct buf *value,
                                      char **content_type,
                                      struct message_guid *guid);

extern void vcard_to_v3(struct vparse_card *vcard);
extern void vcard_to_v4(struct vparse_card *vcard);


#ifdef HAVE_LIBICALVCARD

#include <libical/vcard.h>

extern vcardcomponent *vcard_parse_string_x(const char *str);
extern vcardcomponent *vcard_parse_buf_x(const struct buf *buf);
extern struct buf *vcard_as_buf_x(vcardcomponent *vcard);

extern vcardcomponent *record_to_vcard_x(struct mailbox *mailbox,
                                         const struct index_record *record);

extern size_t vcard_prop_decode_value_x(vcardproperty *prop,
                                        struct buf *value,
                                        char **content_type,
                                        struct message_guid *guid);

extern void vcard_to_v3_x(vcardcomponent *vcard);
extern void vcard_to_v4_x(vcardcomponent *vcard);

extern const char *vcardproperty_get_xparam_value(vcardproperty *prop,
                                                  const char *name);

#endif /* HAVE_LIBICALVCARD */

#endif /* VCARD_SUPPORT_H */

==> cyrus-imapd_3.12.1.orig.tar.xz: cyrus-imapd-3.12.1/imap/vcard_support.h <==
/* vcard_support.h -- Helper functions for vcard
 *
 * Copyright (c) 1994-2016 Carnegie Mellon University.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The name "Carnegie Mellon University" must not be used to
 *    endorse or promote products derived from this software without
 *    prior written permission. For permission or any legal
 *    details, please contact
 *      Carnegie Mellon University
 *      Center for Technology Transfer and Enterprise Creation
 *      4615 Forbes Avenue
 *      Suite 302
 *      Pittsburgh, PA  15213
 *      (412) 268-7393, fax: (412) 268-7395
 *      innovation@andrew.cmu.edu
 *
 * 4. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by Computing Services
 *     at Carnegie Mellon University (http://www.cmu.edu/computing/)."
 *
 * CARNEGIE MELLON UNIVERSITY DISCLAIMS ALL WARRANTIES WITH REGARD TO
 * THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS, IN NO EVENT SHALL CARNEGIE MELLON UNIVERSITY BE LIABLE
 * FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
 * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
 * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 */

#ifndef VCARD_SUPPORT_H
#define VCARD_SUPPORT_H

#include <config.h>

#include "vparse.h"

#include "mailbox.h"
#include "message_guid.h"
#include "util.h"

extern struct vparse_card *vcard_parse_string(const char *str);
extern struct vparse_card *vcard_parse_buf(const struct buf *buf);
extern struct buf *vcard_as_buf(struct vparse_card *vcard);

extern struct vparse_card *record_to_vcard(struct mailbox *mailbox,
                                           const struct index_record *record);

extern size_t vcard_prop_decode_value(struct vparse_entry *prop,
                                      struct buf *value,
                                      char **content_type,
                                      struct message_guid *guid);

extern void vcard_to_v3(struct vparse_card *vcard);
extern void vcard_to_v4(struct vparse_card *vcard);


#ifdef HAVE_LIBICALVCARD

#include <libical/vcard.h>

extern vcardcomponent *vcard_parse_string_x(const char *str);
extern vcardcomponent *vcard_parse_buf_x(const struct buf *buf);
extern struct buf *vcard_as_buf_x(vcardcomponent *vcard);

extern vcardcomponent *record_to_vcard_x(struct mailbox *mailbox,
                                         const struct index_record *record);

extern size_t vcard_prop_decode_value_x(vcardproperty *prop,
                                        struct buf *value,
                                        char **content_type,
                                        struct message_guid *guid);

extern const char *vcardproperty_get_xparam_value(vcardproperty *prop,
                                                  const char *name);

extern void vcardproperty_add_type_parameter(vcardproperty *prop,
                                             vcardenumarray_element *type);
#endif /* HAVE_LIBICALVCARD */

#endif /* VCARD_SUPPORT_H */
